
local StoneGateV5 = ...

-- Apply building asset processor
StoneGateV5:registerAssetProcessor("models/basic/basicLargeGate.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register LargeGate prefab nodes
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_0_LGate_RootPart", "STONE_GATE_V5_LGATE_ROOT_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_0_LGate_RootPart/Pillar1_LGate_Part", "STONE_GATE_V5_LGATE_PILLAR1_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_0_LGate_RootPart/Pillar2_LGate_Part", "STONE_GATE_V5_LGATE_PILLAR2_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_1_LGate_Tiling1Part", "STONE_GATE_V5_LGATE_TILING1_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_2_LGate_Tiling2Part", "STONE_GATE_V5_LGATE_TILING2_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_1_LGate_Tiling1PPart", "STONE_GATE_V5_LGATE_TILING1P_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_2_LGate_Tiling2PPart", "STONE_GATE_V5_LGATE_TILING2P_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_3_LGate_TopPart", "STONE_GATE_V5_LGATE_TOP_PREFAB")
StoneGateV5:registerAssetId("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_3_LGateB_TopPart", "STONE_GATE_V5_LGATEB_TOP_PREFAB")
--------------------------------------------------------------------------

-- Create default building part registering function 
function registerDefaultBuildingPart2(_nodePrefix)
	StoneGateV5:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		    },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		    }
	        },
	        EstateSplendor = {
		    { Estate = "KINGDOM", Quantity = 0.1 }
	    }
	})
end

local defaultNodePrefixList2 = {
        "STONE_GATE_V5_LGATE_PILLAR1",
        "STONE_GATE_V5_LGATE_PILLAR2",
	"STONE_GATE_V5_LGATE_TOP",
	"STONE_GATE_V5_LGATEB_TOP",
	"STONE_GATE_V5_LGATE_TILING1",
	"STONE_GATE_V5_LGATE_TILING2",
	"STONE_GATE_V5_LGATE_TILING1P",
	"STONE_GATE_V5_LGATE_TILING2P"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList2) do
	registerDefaultBuildingPart2(nodePrefix)
end

-- Register the stone gate set main root part
StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = "STONE_GATE_V5_LGATE_ROOT_PART",
	Name = "STONE_GATE_V5_LGATE_ROOT_NAME",
	Description = "STONE_GATE_V5_LGATE_ROOT_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = "STONE_GATE_V5_LGATE_ROOT_PREFAB",
		EndPart = "STONE_GATE_V5_LGATE_TOP_PART",
		FillerList = {
			"STONE_GATE_V5_LGATE_TILING2_PART"
                },
		BasementFillerList = {
			"STONE_GATE_V5_LGATE_TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	}
})

-- Register the stone gate set main root B part
StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = "STONE_GATE_V5_LGATEB_ROOT_PART",
	Name = "STONE_GATE_V5_LGATEB_ROOT_NAME",
	Description = "STONE_GATE_V5_LGATEB_ROOT_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = "STONE_GATE_V5_LGATE_ROOT_PREFAB",
		EndPart = "STONE_GATE_V5_LGATEB_TOP_PART",
		FillerList = {
			"STONE_GATE_V5_LGATE_TILING2_PART"
                },
		BasementFillerList = {
			"STONE_GATE_V5_LGATE_TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	}
})

-- Register the stone gate set main root wooden floor part
StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = "STONE_GATE_V5_LGATE_ROOTP_PART",
	Name = "STONE_GATE_V5_LGATE_ROOTP_NAME",
	Description = "STONE_GATE_V5_LGATE_ROOTP_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = "STONE_GATE_V5_LGATE_ROOT_PREFAB",
		EndPart = "STONE_GATE_V5_LGATE_TOP_PART",
		FillerList = {
			"STONE_GATE_V5_LGATE_TILING2P_PART"
                },
		BasementFillerList = {
			"STONE_GATE_V5_LGATE_TILING1P_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	}
})

--------------------------------------------------------------------------

-- Register flag assigner component on the collider's type to 'PLATFORM'

--StoneGateV5:configurePrefabFlagList("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_3_LGate_TopPart", { "PLATFORM" })
 
-- Register grass clearing components

StoneGateV5:registerPrefabComponent("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_0_LGate_RootPart", {
	DataType = "COMP_DIRT_RECTANGLE",
	Size = { 8, 8 }
})

-- Override building part components properties (generated by the building asset processor) to add building zones
StoneGateV5:registerPrefabComponent("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_0_LGate_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = false,
	BuildingZone = { 0, 0 }
})

StoneGateV5:registerPrefabComponent("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_0_LGate_RootPart/Pillar1_LGate_Part", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 8 }
})

StoneGateV5:registerPrefabComponent("models/basic/basicLargeGate.fbx/Prefab/largeGate/step_0_LGate_RootPart/Pillar2_LGate_Part", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 2, 8 }
})
